@@ -30,12 +30,17 @@ import (
 	"github.com/hashicorp/go-multierror"
 	"github.com/tenable/terrascan/pkg/iac-providers/output"
 	"github.com/tenable/terrascan/pkg/utils"
+
+	. "github.com/onsi/ginkgo"
+	. "github.com/onsi/gomega"
 )
 
 var testDataDir = "testdata"
 
 func TestLoadIacDir(t *testing.T) {
 
+	RegisterFailHandler(Fail)
+
 	invalidDirErr := &os.PathError{Err: syscall.ENOENT, Op: "lstat", Path: filepath.Join(testDataDir, "bad-dir")}
 	if utils.IsWindowsPlatform() {
 		invalidDirErr = &os.PathError{Err: syscall.ENOENT, Op: "CreateFile", Path: filepath.Join(testDataDir, "bad-dir")}
@@ -76,6 +81,24 @@ func TestLoadIacDir(t *testing.T) {
 			wantErr:       multierror.Append(fmt.Errorf("no helm charts found in directory %s", filepath.Join(testDataDir, "no-helm-charts"))),
 			resourceCount: 0,
 		},
+		{
+			name:          "happy path with multiple values files merged",
+			dirPath:       filepath.Join(testDataDir, "multiple-values-file"),
+			helmv3:        HelmV3{},
+			resourceCount: 3,
+			options: map[string]interface{}{
+				"valuesFiles": []string{"values1.yaml", "values2.yaml"},
+			},
+		},
+		{
+			name:          "happy path with multiple values files merged values1 override",
+			dirPath:       filepath.Join(testDataDir, "multiple-values-file"),
+			helmv3:        HelmV3{},
+			resourceCount: 3,
+			options: map[string]interface{}{
+				"valuesFiles": []string{"values2.yaml", "values1.yaml"},
+			},
+		},
 	}
 
 	for _, tt := range table {
@@ -97,6 +120,19 @@ func TestLoadIacDir(t *testing.T) {
 			if resCount != tt.resourceCount {
 				t.Errorf("resource count (%d) does not match expected (%d)", resCount, tt.resourceCount)
 			}
+			if tt.name == "happy path (credit to madhuakula/kubernetes-goat)" {
+				deploymentValue := resources["kubernetes_deployment"][0]
+				expectedInage := deploymentValue.ContainerImages[0].Image
+				Expect(expectedInage).To(Equal("madhuakula/k8s-goat-metadata-db:latest"))
+			} else if tt.name == "happy path with multiple values files merged" {
+				deploymentValue := resources["kubernetes_deployment"][0]
+				expectedInage := deploymentValue.ContainerImages[0].Image
+				Expect(expectedInage).To(Equal("madhuakula/k8s-goat-metadata-db-sample2:latest"))
+			} else if tt.name == "happy path with multiple values files merged values1 override" {
+				deploymentValue := resources["kubernetes_deployment"][0]
+				expectedInage := deploymentValue.ContainerImages[0].Image
+				Expect(expectedInage).To(Equal("madhuakula/k8s-goat-metadata-db:latest"))
+			}
 		})
 	}
 
@@ -109,13 +145,14 @@ func TestLoadChart(t *testing.T) {
 	unreadableChartFileErr := &os.PathError{Err: syscall.EISDIR, Op: "read", Path: filepath.Join(testDataDir, "bad-chart-file")}
 	chartPathUnreadableValuesErr := &os.PathError{Err: syscall.EISDIR, Op: "read", Path: filepath.Join(testDataDir, "chart-unreadable-values", "values.yaml")}
 	chartPathBadTemplateErr := &os.PathError{Err: syscall.EISDIR, Op: "read", Path: filepath.Join(testDataDir, "chart-bad-template-file", "templates", "service.yaml")}
-
+	chartPathNoCustomValuesYAMLErr := &os.PathError{Err: syscall.ENOENT, Op: "stat", Path: filepath.Join(testDataDir, "chart-no-values", "custom-values.yaml")}
 	if utils.IsWindowsPlatform() {
 		chartPathNoValuesYAMLErr = &os.PathError{Err: syscall.ENOENT, Op: "CreateFile", Path: filepath.Join(testDataDir, "chart-no-values", "values.yaml")}
 		chartPathNoTemplateDirErr = &os.PathError{Err: syscall.ENOENT, Op: "CreateFile", Path: filepath.Join(testDataDir, "chart-no-template-dir", "templates")}
 		unreadableChartFileErr = &os.PathError{Err: syscall.Errno(6), Op: "read", Path: filepath.Join(testDataDir, "bad-chart-file")}
 		chartPathUnreadableValuesErr = &os.PathError{Err: syscall.Errno(6), Op: "read", Path: filepath.Join(testDataDir, "chart-unreadable-values", "values.yaml")}
 		chartPathBadTemplateErr = &os.PathError{Err: syscall.Errno(6), Op: "read", Path: filepath.Join(testDataDir, "chart-bad-template-file", "templates", "service.yaml")}
+		chartPathNoCustomValuesYAMLErr = &os.PathError{Err: syscall.ENOENT, Op: "CreateFile", Path: filepath.Join(testDataDir, "chart-no-values", "custom-values.yaml")}
 	}
 
 	table := []struct {
@@ -124,6 +161,7 @@ func TestLoadChart(t *testing.T) {
 		helmv3    HelmV3
 		want      output.AllResourceConfigs
 		wantErr   error
+		options   map[string]interface{}
 	}{
 		{
 			name:      "happy path (credit to madhuakula/kubernetes-goat)",
@@ -159,7 +197,7 @@ func TestLoadChart(t *testing.T) {
 			name:      "chart path with unreadable values.yaml",
 			chartPath: filepath.Join(testDataDir, "chart-bad-values", "Chart.yaml"),
 			helmv3:    HelmV3{},
-			wantErr:   &yaml.TypeError{Errors: []string{"line 1: cannot unmarshal !!str `:bad <bad` into map[string]interface {}"}},
+			wantErr:   &yaml.TypeError{Errors: []string{"line 1: cannot unmarshal !!str `:bad <bad` into map[interface {}]interface {}"}},
 		},
 		{
 			name:      "chart path no template dir",
@@ -197,11 +235,20 @@ func TestLoadChart(t *testing.T) {
 			helmv3:    HelmV3{},
 			wantErr:   fmt.Errorf("parse error at (%s:40): unexpected {{end}}", path.Join("metadata-db", filepath.Join("templates", "ingress.yaml"))),
 		},
+		{
+			name:      "chart path with no values.yaml file in custom values.yaml",
+			chartPath: filepath.Join(testDataDir, "chart-no-values", "Chart.yaml"),
+			helmv3:    HelmV3{},
+			wantErr:   chartPathNoCustomValuesYAMLErr,
+			options: map[string]interface{}{
+				"valuesFiles": []string{"custom-values.yaml"},
+			},
+		},
 	}
 
 	for _, tt := range table {
 		t.Run(tt.name, func(t *testing.T) {
-			_, _, gotErr := tt.helmv3.loadChart(tt.chartPath)
+			_, _, gotErr := tt.helmv3.loadChart(tt.chartPath, tt.options)
 			if !reflect.DeepEqual(gotErr, tt.wantErr) {
 				t.Errorf("unexpected error; gotErr: '%v', wantErr: '%v'", gotErr, tt.wantErr)
 			}
