@@ -6,4 +6,4 @@ set -o pipefail
 
 export TERRASCAN_BIN_PATH=${PWD}/bin/terrascan
 
-go test -p 1 -v ./test/...
\ No newline at end of file
+go test -p 1 -v $(go list ./test/e2e/... | grep -v /vulnerability) 
\ No newline at end of file
